### REFERENCES AND NOTES

* [1] Grósz Tímea, „Mikrostruktúráltoptikai szálakdiszperziójánakvizsgálata spektrális interferometriával” Ph.D.  értekezés,  Szegedi  Tudományegyetem, Optikai  és  Kvantumelektronikai  Tanszék, Szeged (2017).
* [2] Kovács Attila, „Optikai elemek fázistulajdonságainak interferometrikus vizsgálata,” Ph.D.  értekezés,  Szegedi  Tudományegyetem,  Optikai  és  Kvantumelektronikai  Tanszék, Szeged (2000).
* [3] C. Dorrer, N. Belabas, J-P. Likforman, and M. Joffre, „Spectral resolution and sampling issues in Fourier-transform spectral interferometry”, J. Opt. Soc. Am. B 17, 1795 (2000)
* [4] L. Huang, Q. Kemao, B. Pan, and A. K. Asundi, „Comparison of Fourier transform, windowed  Fourier  transform,  and  wavelet  transform  methods  for  phase  extraction  from  asingle  fringe  pattern  in  fringe  projection  profilometry,”  Opt.  Laser  Eng. 48,  141–148 (2010).
* [5]  Jean-Paul. Peak signal detection in realtime timeseries data [Msg 104]. Message posted to Stackoverflow [Internet]. 2014 [cited 2019.10.29.]. 
	   Available from: https://stackoverflow.com/questions/22583391/peak-signal-detection-in-realtime-timeseries-data.